You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by ds...@apache.org on 2016/09/15 21:01:45 UTC

[28/76] [abbrv] [partial] incubator-geode git commit: GEODE-37 changed import to org.apache.geode

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DSClock.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DSClock.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DSClock.java
index d96e7c3..b759b2e 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DSClock.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DSClock.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
-
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.internal.SystemTimer;
-import com.gemstone.gemfire.internal.SystemTimer.SystemTimerTask;
-import com.gemstone.gemfire.internal.cache.GemFireCacheImpl;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.DateFormatter;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+package org.apache.geode.distributed.internal;
+
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.internal.SystemTimer;
+import org.apache.geode.internal.SystemTimer.SystemTimerTask;
+import org.apache.geode.internal.cache.GemFireCacheImpl;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.DateFormatter;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 import org.apache.logging.log4j.Logger;
 
 import java.util.Date;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DefaultServerLauncherCacheProvider.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DefaultServerLauncherCacheProvider.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DefaultServerLauncherCacheProvider.java
index 6f155ad..7b4ca94 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DefaultServerLauncherCacheProvider.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DefaultServerLauncherCacheProvider.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.util.Properties;
 
-import com.gemstone.gemfire.cache.Cache;
-import com.gemstone.gemfire.cache.CacheFactory;
-import com.gemstone.gemfire.distributed.ServerLauncher;
-import com.gemstone.gemfire.distributed.ServerLauncherCacheProvider;
-import com.gemstone.gemfire.internal.cache.CacheConfig;
+import org.apache.geode.cache.Cache;
+import org.apache.geode.cache.CacheFactory;
+import org.apache.geode.distributed.ServerLauncher;
+import org.apache.geode.distributed.ServerLauncherCacheProvider;
+import org.apache.geode.internal.cache.CacheConfig;
 
 public class DefaultServerLauncherCacheProvider
     implements ServerLauncherCacheProvider {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DirectReplyProcessor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DirectReplyProcessor.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DirectReplyProcessor.java
index fa06c4e..6fcb080 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DirectReplyProcessor.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DirectReplyProcessor.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.util.Collection;
 import java.util.Collections;
 
-import com.gemstone.gemfire.CancelCriterion;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.CancelCriterion;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 
 /**
  * A reply processor optimized for direct ack responses (It skips synchronization,

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisee.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisee.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisee.java
index 655b9d1..3b137b7 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisee.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisee.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import com.gemstone.gemfire.CancelCriterion;
-import com.gemstone.gemfire.distributed.internal.DM;
-import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
-import com.gemstone.gemfire.distributed.internal.DistributionAdvisor.Profile;
+import org.apache.geode.CancelCriterion;
+import org.apache.geode.distributed.internal.DM;
+import org.apache.geode.distributed.internal.InternalDistributedSystem;
+import org.apache.geode.distributed.internal.DistributionAdvisor.Profile;
 
 /**
  * Resource which uses a {@link DistributionAdvisor}.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisor.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisor.java
index c93eeb3..843c478 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisor.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionAdvisor.java
@@ -15,25 +15,25 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
-
-import com.gemstone.gemfire.CancelException;
-import com.gemstone.gemfire.GemFireIOException;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.DataSerializableFixedID;
-import com.gemstone.gemfire.internal.InternalDataSerializer;
-import com.gemstone.gemfire.internal.Version;
-import com.gemstone.gemfire.internal.cache.CacheDistributionAdvisor.CacheProfile;
-import com.gemstone.gemfire.internal.cache.DistributedRegion;
-import com.gemstone.gemfire.internal.cache.UpdateAttributesProcessor;
-import com.gemstone.gemfire.internal.cache.persistence.PersistentMemberID;
-import com.gemstone.gemfire.internal.cache.versions.VersionSource;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
-import com.gemstone.gemfire.internal.util.ArrayUtils;
+package org.apache.geode.distributed.internal;
+
+import org.apache.geode.CancelException;
+import org.apache.geode.GemFireIOException;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.DataSerializableFixedID;
+import org.apache.geode.internal.InternalDataSerializer;
+import org.apache.geode.internal.Version;
+import org.apache.geode.internal.cache.CacheDistributionAdvisor.CacheProfile;
+import org.apache.geode.internal.cache.DistributedRegion;
+import org.apache.geode.internal.cache.UpdateAttributesProcessor;
+import org.apache.geode.internal.cache.persistence.PersistentMemberID;
+import org.apache.geode.internal.cache.versions.VersionSource;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.internal.logging.log4j.LogMarker;
+import org.apache.geode.internal.util.ArrayUtils;
 import org.apache.logging.log4j.Logger;
 
 import java.io.DataInput;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionChannel.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionChannel.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionChannel.java
index e96753f..c8f7b05 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionChannel.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionChannel.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.io.NotSerializableException;
 import java.util.HashSet;
@@ -22,13 +22,13 @@ import java.util.Set;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.distributed.DistributedSystemDisconnectedException;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.distributed.internal.membership.MembershipManager;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
+import org.apache.geode.distributed.DistributedSystemDisconnectedException;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.distributed.internal.membership.MembershipManager;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.internal.logging.log4j.LogMarker;
 
 /**
  * To change this generated comment edit the template variable "typecomment":

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfig.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfig.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfig.java
index e137273..692c2b9 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfig.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfig.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 import java.io.File;
 import java.lang.reflect.Field;
@@ -30,15 +30,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import com.gemstone.gemfire.distributed.ConfigurationProperties;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.internal.Config;
-import com.gemstone.gemfire.internal.ConfigSource;
-import com.gemstone.gemfire.internal.logging.InternalLogWriter;
-import com.gemstone.gemfire.internal.logging.LogConfig;
-import com.gemstone.gemfire.internal.security.SecurableCommunicationChannel;
-import com.gemstone.gemfire.internal.tcp.Connection;
-import com.gemstone.gemfire.memcached.GemFireMemcachedServer;
+import org.apache.geode.distributed.ConfigurationProperties;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.internal.Config;
+import org.apache.geode.internal.ConfigSource;
+import org.apache.geode.internal.logging.InternalLogWriter;
+import org.apache.geode.internal.logging.LogConfig;
+import org.apache.geode.internal.security.SecurableCommunicationChannel;
+import org.apache.geode.internal.tcp.Connection;
+import org.apache.geode.memcached.GemFireMemcachedServer;
 
 /**
  * Provides accessor (and in some cases mutator) methods for the
@@ -49,7 +49,7 @@ import com.gemstone.gemfire.memcached.GemFireMemcachedServer;
  * <p>
  * <p>
  * Descriptions of these properties can be found {@link ConfigurationProperties}.
- * @see com.gemstone.gemfire.internal.Config
+ * @see org.apache.geode.internal.Config
  * @since GemFire 2.1
  */
 public interface DistributionConfig extends Config, LogConfig {
@@ -77,8 +77,8 @@ public interface DistributionConfig extends Config, LogConfig {
    * Sets the member's name.
    * <p> The name can not be changed while the system is running.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    */
   @ConfigAttributeSetter(name = NAME)
@@ -300,8 +300,8 @@ public interface DistributionConfig extends Config, LogConfig {
    * Multiple elements are allowed and must be seperated by a comma.
    *
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    */
   @ConfigAttributeSetter(name = LOCATORS)
@@ -368,8 +368,8 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Sets the system's deploy working directory.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    */
   @ConfigAttributeSetter(name = DEPLOY_WORKING_DIR)
@@ -396,8 +396,8 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Sets the system's user command path.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    */
   @ConfigAttributeSetter(name = USER_COMMAND_PACKAGES)
@@ -427,8 +427,8 @@ public interface DistributionConfig extends Config, LogConfig {
    * <p> Non-absolute log files are relative to the system directory.
    * <p> The system log file can not be changed while the system is running.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    */
 
@@ -450,14 +450,14 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * Returns the value of the {@link ConfigurationProperties#LOG_LEVEL} property
-   * @see com.gemstone.gemfire.internal.logging.LogWriterImpl
+   * @see org.apache.geode.internal.logging.LogWriterImpl
    */
   @ConfigAttributeGetter(name = LOG_LEVEL)
   int getLogLevel();
 
   /**
    * Sets the value of the {@link ConfigurationProperties#LOG_LEVEL} property
-   * @see com.gemstone.gemfire.internal.logging.LogWriterImpl
+   * @see org.apache.geode.internal.logging.LogWriterImpl
    */
   @ConfigAttributeSetter(name = LOG_LEVEL)
   void setLogLevel(int value);
@@ -1078,7 +1078,7 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of an internal property that specifies a {@link
-   * com.gemstone.gemfire.i18n.LogWriterI18n} instance to log to.
+   * org.apache.geode.i18n.LogWriterI18n} instance to log to.
    * Set this property with put(), not with setProperty()
    * @since GemFire 4.0
    */
@@ -1111,7 +1111,7 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of an internal property that specifies a {@link
-   * com.gemstone.gemfire.LogWriter} instance to log security messages to. Set
+   * org.apache.geode.LogWriter} instance to log security messages to. Set
    * this property with put(), not with setProperty()
    * @since GemFire 5.5
    */
@@ -2229,8 +2229,8 @@ public interface DistributionConfig extends Config, LogConfig {
    * <p>
    * The security log file can not be changed while the system is running.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error when writing to
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error when writing to
    * the system's configuration file.
    */
   @ConfigAttributeSetter(name = SECURITY_LOG_FILE)
@@ -2479,8 +2479,8 @@ public interface DistributionConfig extends Config, LogConfig {
    * Sets the {@link ConfigurationProperties#GROUPS} property.
    * <p> The groups can not be changed while the system is running.
    * @throws IllegalArgumentException if the specified value is not acceptable.
-   * @throws com.gemstone.gemfire.UnmodifiableException if this attribute can not be modified.
-   * @throws com.gemstone.gemfire.GemFireIOException if the set failure is caused by an error
+   * @throws org.apache.geode.UnmodifiableException if this attribute can not be modified.
+   * @throws org.apache.geode.GemFireIOException if the set failure is caused by an error
    * when writing to the system's configuration file.
    * @since GemFire 7.0
    */
@@ -2571,7 +2571,7 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_ENABLED} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -2642,8 +2642,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_JMX_MANAGER_SSL_PROTOCOLS = "any";
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_PROTOCOLS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_PROTOCOLS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_PROTOCOLS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -2676,8 +2676,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_JMX_MANAGER_SSL_CIPHERS = "any";
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_CIPHERS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_CIPHERS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_CIPHERS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -2710,8 +2710,8 @@ public interface DistributionConfig extends Config, LogConfig {
   boolean DEFAULT_JMX_MANAGER_SSL_REQUIRE_AUTHENTICATION = true;
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_REQUIRE_AUTHENTICATION} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_REQUIRE_AUTHENTICATION} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_REQUIRE_AUTHENTICATION} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -2745,8 +2745,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -2780,8 +2780,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_TYPE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_TYPE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_TYPE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
    */
   @ConfigAttribute(type = String.class)
   String JMX_MANAGER_SSL_KEYSTORE_TYPE_NAME = JMX_MANAGER_SSL_KEYSTORE_TYPE;
@@ -2814,7 +2814,7 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_PASSWORD} propery
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_KEYSTORE_PASSWORD} propery
    * @deprecated Geode 1.0 use {@link #DEFAULT_SSL_KEYSTORE_PASSWORD}
    */
   @Deprecated
@@ -2849,8 +2849,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
    */
   @ConfigAttribute(type = String.class)
   String JMX_MANAGER_SSL_TRUSTSTORE_NAME = JMX_MANAGER_SSL_TRUSTSTORE;
@@ -2883,8 +2883,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_SSL_TRUSTSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -2933,7 +2933,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property
    * @deprecated as of 8.0 use {@link #getHttpServicePort()} instead.
    */
   @ConfigAttributeGetter(name = JMX_MANAGER_HTTP_PORT)
@@ -2942,7 +2942,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Set the {@link ConfigurationProperties#JMX_MANAGER_HTTP_PORT} for jmx-manager.
    * <p>
-   * Set the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} for jmx-manager.
+   * Set the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} for jmx-manager.
    * @param value the port number for jmx-manager HTTP service
    *
    * @deprecated as of 8.0 use {@link #setHttpServicePort(int)} instead.
@@ -2953,7 +2953,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * The name of the {@link ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property.
    * <p>
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property.
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#JMX_MANAGER_HTTP_PORT} property.
    * @deprecated as of 8.0 use {{@link #HTTP_SERVICE_PORT_NAME} instead.
    */
   @ConfigAttribute(type = Integer.class, min = 0, max = 65535)
@@ -2981,7 +2981,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#MEMCACHED_PORT} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#MEMCACHED_PORT} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#MEMCACHED_PORT} property
    * @return the port on which GemFireMemcachedServer should be started
    *
    * @since GemFire 7.0
@@ -2999,7 +2999,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#MEMCACHED_PROTOCOL} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#MEMCACHED_PROTOCOL} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#MEMCACHED_PROTOCOL} property
    * @return the protocol for GemFireMemcachedServer
    *
    * @since GemFire 7.0
@@ -3017,7 +3017,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#MEMCACHED_BIND_ADDRESS} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#MEMCACHED_BIND_ADDRESS} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#MEMCACHED_BIND_ADDRESS} property
    * @return the bind address for GemFireMemcachedServer
    *
    * @since GemFire 7.0
@@ -3051,7 +3051,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#REDIS_BIND_ADDRESS} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#REDIS_BIND_ADDRESS} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#REDIS_BIND_ADDRESS} property
    * @return the bind address for GemFireRedisServer
    *
    * @since GemFire 8.0
@@ -3069,7 +3069,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#REDIS_PASSWORD} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#REDIS_PASSWORD} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#REDIS_PASSWORD} property
    * @return the authentication password for GemFireRedisServer
    *
    * @since GemFire 8.0
@@ -3089,7 +3089,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#HTTP_SERVICE_PORT} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} property
    * @return the HTTP service port
    *
    * @since GemFire 8.0
@@ -3100,7 +3100,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Set the {@link ConfigurationProperties#HTTP_SERVICE_PORT} for HTTP service.
    * <p>
-   * Set the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} for HTTP service.
+   * Set the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} for HTTP service.
    * @param value the port number for HTTP service
    *
    * @since GemFire 8.0
@@ -3111,7 +3111,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_PORT} property
    * <p>
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} property
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_PORT} property
    * @since GemFire 8.0
    */
   @ConfigAttribute(type = Integer.class, min = 0, max = 65535)
@@ -3127,7 +3127,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} property
    * @return the bind-address for HTTP service
    *
    * @since GemFire 8.0
@@ -3138,7 +3138,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Set the {@link ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} for HTTP service.
    * <p>
-   * Set the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} for HTTP service.
+   * Set the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_BIND_ADDRESS} for HTTP service.
    * @param value the bind-address for HTTP service
    *
    * @since GemFire 8.0
@@ -3190,8 +3190,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_ENABLED} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_ENABLED} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_ENABLED} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -3225,8 +3225,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_REQUIRE_AUTHENTICATION} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_REQUIRE_AUTHENTICATION} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_REQUIRE_AUTHENTICATION} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -3260,8 +3260,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_PROTOCOLS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_PROTOCOLS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_PROTOCOLS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3295,8 +3295,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_CIPHERS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_CIPHERS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_CIPHERS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3330,8 +3330,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3365,8 +3365,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3399,8 +3399,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_TYPE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_TYPE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_KEYSTORE_TYPE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3434,8 +3434,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3469,8 +3469,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#HTTP_SERVICE_SSL_TRUSTSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3487,7 +3487,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Returns the value of the {@link ConfigurationProperties#START_DEV_REST_API} property
    * <p>
-   * Returns the value of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#START_DEV_REST_API} property
+   * Returns the value of the {@link org.apache.geode.distributed.ConfigurationProperties#START_DEV_REST_API} property
    * @return the value of the property
    *
    * @since GemFire 8.0
@@ -3499,7 +3499,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Set the {@link ConfigurationProperties#START_DEV_REST_API} for HTTP service.
    * <p>
-   * Set the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#START_DEV_REST_API} for HTTP service.
+   * Set the {@link org.apache.geode.distributed.ConfigurationProperties#START_DEV_REST_API} for HTTP service.
    * @param value for the property
    *
    * @since GemFire 8.0
@@ -3510,7 +3510,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * The name of the {@link ConfigurationProperties#START_DEV_REST_API} property
    * <p>
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#START_DEV_REST_API} property
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#START_DEV_REST_API} property
    * @since GemFire 8.0
    */
   @ConfigAttribute(type = Boolean.class)
@@ -3572,8 +3572,8 @@ public interface DistributionConfig extends Config, LogConfig {
   boolean DEFAULT_SERVER_SSL_ENABLED = false;
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_ENABLED} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_ENABLED} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_ENABLED}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_ENABLED} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_ENABLED}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -3613,8 +3613,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_SERVER_SSL_PROTOCOLS = "any";
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_PROTOCOLS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_PROTOCOLS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_PROTOCOLS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3647,8 +3647,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_SERVER_SSL_CIPHERS = "any";
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_CIPHERS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_CIPHERS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}�
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_CIPHERS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}�
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3681,8 +3681,8 @@ public interface DistributionConfig extends Config, LogConfig {
   boolean DEFAULT_SERVER_SSL_REQUIRE_AUTHENTICATION = true;
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_REQUIRE_AUTHENTICATION} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_REQUIRE_AUTHENTICATION} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_REQUIRE_AUTHENTICATION} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -3716,8 +3716,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_KEYSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3751,8 +3751,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_KEYSTORE_TYPE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE_TYPE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE_TYPE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3786,8 +3786,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_KEYSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_KEYSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3820,8 +3820,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_TRUSTSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_TRUSTSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_TRUSTSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3855,8 +3855,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#SERVER_SSL_TRUSTSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#SERVER_SSL_TRUSTSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#SERVER_SSL_TRUSTSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3880,8 +3880,8 @@ public interface DistributionConfig extends Config, LogConfig {
   boolean DEFAULT_GATEWAY_SSL_ENABLED = false;
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_ENABLED} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_ENABLED} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_ENABLED} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_ENABLED}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -3922,8 +3922,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_GATEWAY_SSL_PROTOCOLS = "any";
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_PROTOCOLS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_PROTOCOLS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_PROTOCOLS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_PROTOCOLS}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3955,8 +3955,8 @@ public interface DistributionConfig extends Config, LogConfig {
   String DEFAULT_GATEWAY_SSL_CIPHERS = "any";
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_CIPHERS} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_CIPHERS} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}�
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_CIPHERS} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_CIPHERS}�
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -3989,8 +3989,8 @@ public interface DistributionConfig extends Config, LogConfig {
   boolean DEFAULT_GATEWAY_SSL_REQUIRE_AUTHENTICATION = true;
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_REQUIRE_AUTHENTICATION} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_REQUIRE_AUTHENTICATION} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_REQUIRE_AUTHENTICATION} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_REQUIRE_AUTHENTICATION}
    */
   @Deprecated
   @ConfigAttribute(type = Boolean.class)
@@ -4024,8 +4024,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_KEYSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -4059,8 +4059,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_KEYSTORE_TYPE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE_TYPE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE_TYPE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_TYPE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -4094,8 +4094,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_KEYSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_KEYSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_KEYSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -4129,8 +4129,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -4164,8 +4164,8 @@ public interface DistributionConfig extends Config, LogConfig {
 
   /**
    * The name of the {@link ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE_PASSWORD} property
-   * The name of the {@link com.gemstone.gemfire.distributed.ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE_PASSWORD} property
-   * @deprecated Geode 1.0 use {@link com.gemstone.gemfire.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
+   * The name of the {@link org.apache.geode.distributed.ConfigurationProperties#GATEWAY_SSL_TRUSTSTORE_PASSWORD} property
+   * @deprecated Geode 1.0 use {@link org.apache.geode.distributed.ConfigurationProperties#CLUSTER_SSL_TRUSTSTORE_PASSWORD}
    */
   @Deprecated
   @ConfigAttribute(type = String.class)
@@ -4192,7 +4192,7 @@ public interface DistributionConfig extends Config, LogConfig {
   /**
    * Gets the value of {@link ConfigurationProperties#LOCK_MEMORY}
    * <p>
-   * Gets the value of {@link com.gemstone.gemfire.distributed.ConfigurationProperties#LOCK_MEMORY}
+   * Gets the value of {@link org.apache.geode.distributed.ConfigurationProperties#LOCK_MEMORY}
    * @since Geode 1.0
    */
   @ConfigAttributeGetter(name = LOCK_MEMORY)

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigImpl.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigImpl.java
index c5df689..5a3ec27 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigImpl.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import static com.gemstone.gemfire.distributed.ConfigurationProperties.*;
+import static org.apache.geode.distributed.ConfigurationProperties.*;
 
 import java.io.File;
 import java.io.IOException;
@@ -40,18 +40,18 @@ import org.apache.commons.lang.builder.HashCodeBuilder;
 import org.apache.geode.redis.GeodeRedisServer;
 import org.apache.geode.security.SecurableComponents;
 
-import com.gemstone.gemfire.GemFireConfigException;
-import com.gemstone.gemfire.GemFireIOException;
-import com.gemstone.gemfire.InternalGemFireException;
-import com.gemstone.gemfire.distributed.ConfigurationProperties;
-import com.gemstone.gemfire.distributed.DistributedSystem;
-import com.gemstone.gemfire.internal.ConfigSource;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.process.ProcessLauncherContext;
-import com.gemstone.gemfire.internal.security.SecurableCommunicationChannel;
-import com.gemstone.gemfire.internal.security.SecurableComponent;
-import com.gemstone.gemfire.memcached.GemFireMemcachedServer;
+import org.apache.geode.GemFireConfigException;
+import org.apache.geode.GemFireIOException;
+import org.apache.geode.InternalGemFireException;
+import org.apache.geode.distributed.ConfigurationProperties;
+import org.apache.geode.distributed.DistributedSystem;
+import org.apache.geode.internal.ConfigSource;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.process.ProcessLauncherContext;
+import org.apache.geode.internal.security.SecurableCommunicationChannel;
+import org.apache.geode.internal.security.SecurableComponent;
+import org.apache.geode.memcached.GemFireMemcachedServer;
 
 /**
  * Provides an implementation of <code>DistributionConfig</code> that
@@ -132,7 +132,7 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
 
   /**
    * The level at which log messages are logged
-   * @see com.gemstone.gemfire.internal.logging.LogWriterImpl#levelNameToCode(String)
+   * @see org.apache.geode.internal.logging.LogWriterImpl#levelNameToCode(String)
    */
   protected int logLevel = DEFAULT_LOG_LEVEL;
 
@@ -332,7 +332,7 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
 
   /**
    * The level at which security related log messages are logged
-   * @see com.gemstone.gemfire.internal.logging.LogWriterImpl#levelNameToCode(String)
+   * @see org.apache.geode.internal.logging.LogWriterImpl#levelNameToCode(String)
    */
   protected int securityLogLevel = DEFAULT_LOG_LEVEL;
 
@@ -815,7 +815,7 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
   /**
    * Creates a new <code>DistributionConfigImpl</code> with the given
    * non-default configuration properties.  See {@link
-   * com.gemstone.gemfire.distributed.DistributedSystem#connect} for a
+   * org.apache.geode.distributed.DistributedSystem#connect} for a
    * list of exceptions that may be thrown.
    * @param nonDefault The configuration properties specified by the caller
    */
@@ -826,7 +826,7 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
   /**
    * Creates a new <code>DistributionConfigImpl</code> with the given
    * non-default configuration properties. See
-   * {@link com.gemstone.gemfire.distributed.DistributedSystem#connect} for a
+   * {@link org.apache.geode.distributed.DistributedSystem#connect} for a
    * list of exceptions that may be thrown.
    * @param nonDefault The configuration properties specified by the caller
    * @param ignoreGemFirePropsFile whether to skip loading distributed system properties from
@@ -842,7 +842,7 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
   /**
    * Creates a new <code>DistributionConfigImpl</code> with the given
    * non-default configuration properties. See
-   * {@link com.gemstone.gemfire.distributed.DistributedSystem#connect} for a
+   * {@link org.apache.geode.distributed.DistributedSystem#connect} for a
    * list of exceptions that may be thrown.
    * @param nonDefault The configuration properties specified by the caller
    * @param ignoreGemFirePropsFile whether to skip loading distributed system properties from
@@ -3095,14 +3095,14 @@ public class DistributionConfigImpl extends AbstractDistributionConfig implement
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.distributed.internal.DistributionConfig#getMembershipPortRange()
+   * @see org.apache.geode.distributed.internal.DistributionConfig#getMembershipPortRange()
    */
   public int[] getMembershipPortRange() {
     return membershipPortRange;
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.distributed.internal.DistributionConfig#setMembershipPortRange(int[])
+   * @see org.apache.geode.distributed.internal.DistributionConfig#setMembershipPortRange(int[])
    */
   public void setMembershipPortRange(int[] range) {
     membershipPortRange = (int[]) range;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigSnapshot.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigSnapshot.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigSnapshot.java
index d50ff74..9d55437 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigSnapshot.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionConfigSnapshot.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.util.HashSet;
 
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 /**
  * Provides an implementation of the {@link DistributionConfig} interface

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionException.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionException.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionException.java
index 7254504..6bfa55b 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionException.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionException.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import com.gemstone.gemfire.GemFireException;
+import org.apache.geode.GemFireException;
 
 /**
  * This exception is thrown when a problem occurs when accessing the

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionManager.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessage.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessage.java
index f93e652..f07dca4 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessage.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessage.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -28,32 +28,32 @@ import java.util.concurrent.RejectedExecutionException;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.CancelException;
-import com.gemstone.gemfire.InternalGemFireException;
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.distributed.internal.deadlock.MessageDependencyMonitor;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.DataSerializableFixedID;
-import com.gemstone.gemfire.internal.Version;
-import com.gemstone.gemfire.internal.cache.EventID;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
-import com.gemstone.gemfire.internal.sequencelog.MessageLogger;
-import com.gemstone.gemfire.internal.tcp.Connection;
-import com.gemstone.gemfire.internal.util.Breadcrumbs;
+import org.apache.geode.CancelException;
+import org.apache.geode.InternalGemFireException;
+import org.apache.geode.SystemFailure;
+import org.apache.geode.distributed.internal.deadlock.MessageDependencyMonitor;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.DataSerializableFixedID;
+import org.apache.geode.internal.Version;
+import org.apache.geode.internal.cache.EventID;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.internal.logging.log4j.LogMarker;
+import org.apache.geode.internal.sequencelog.MessageLogger;
+import org.apache.geode.internal.tcp.Connection;
+import org.apache.geode.internal.util.Breadcrumbs;
 
 /**
  * <P>A <code>DistributionMessage</code> carries some piece of
  * information to a distribution manager.  </P>
  *
  * <P>Messages that don't have strict ordering requirements should extend
- * {@link com.gemstone.gemfire.distributed.internal.PooledDistributionMessage}.
+ * {@link org.apache.geode.distributed.internal.PooledDistributionMessage}.
  * Messages that must be processed serially in the order they were received
  * can extend
- * {@link com.gemstone.gemfire.distributed.internal.SerialDistributionMessage}.
+ * {@link org.apache.geode.distributed.internal.SerialDistributionMessage}.
  * To customize the sequentialness/thread requirements of a message, extend
  * DistributionMessage and implement getExecutor().</P>
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessageObserver.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessageObserver.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessageObserver.java
index 3b4161c..d5afe6d 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessageObserver.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessageObserver.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionStats.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionStats.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionStats.java
index fbfd0c6..ca2a8c1 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionStats.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionStats.java
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.StatisticDescriptor;
-import com.gemstone.gemfire.Statistics;
-import com.gemstone.gemfire.StatisticsFactory;
-import com.gemstone.gemfire.StatisticsType;
-import com.gemstone.gemfire.StatisticsTypeFactory;
-import com.gemstone.gemfire.internal.NanoTimer;
-import com.gemstone.gemfire.internal.statistics.StatisticsTypeFactoryImpl;
-import com.gemstone.gemfire.internal.logging.LogService;
+import org.apache.geode.StatisticDescriptor;
+import org.apache.geode.Statistics;
+import org.apache.geode.StatisticsFactory;
+import org.apache.geode.StatisticsType;
+import org.apache.geode.StatisticsTypeFactory;
+import org.apache.geode.internal.NanoTimer;
+import org.apache.geode.internal.statistics.StatisticsTypeFactoryImpl;
+import org.apache.geode.internal.logging.LogService;
 //import java.io.*;
-import com.gemstone.gemfire.internal.tcp.Buffers;
-import com.gemstone.gemfire.internal.util.Breadcrumbs;
+import org.apache.geode.internal.tcp.Buffers;
+import org.apache.geode.internal.util.Breadcrumbs;
 
 /**
  * This class maintains statistics in GemFire about the distribution

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/FlowControlParams.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/FlowControlParams.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/FlowControlParams.java
index b656805..c4c7b83 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/FlowControlParams.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/FlowControlParams.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /** FlowControlParams are used to represent mcast-flow-control parameters for a
     DistributedSystem.  Instances of this class are used in DistributionConfig to

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/FunctionExecutionPooledExecutor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/FunctionExecutionPooledExecutor.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/FunctionExecutionPooledExecutor.java
index 1ac6f30..6a05591 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/FunctionExecutionPooledExecutor.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/FunctionExecutionPooledExecutor.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import com.gemstone.gemfire.SystemFailure;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
+import org.apache.geode.SystemFailure;
+import org.apache.geode.internal.i18n.LocalizedStrings;
 
 import java.util.List;
 import java.util.concurrent.*;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitor.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitor.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitor.java
index 92cafe8..46da196 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitor.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitor.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
    
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
-import com.gemstone.gemfire.admin.GemFireHealth;
+import org.apache.geode.admin.GemFireHealth;
 
 /**
  * Represents a thread that monitor the health of the vm it lives in.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitorImpl.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitorImpl.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitorImpl.java
index 7862390..5773583 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitorImpl.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/HealthMonitorImpl.java
@@ -15,19 +15,19 @@
  * limitations under the License.
  */
    
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.admin.GemFireHealth;
-import com.gemstone.gemfire.admin.GemFireHealthConfig;
-import com.gemstone.gemfire.admin.internal.GemFireHealthEvaluator;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.admin.remote.HealthListenerMessage;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LoggingThreadGroup;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.admin.GemFireHealth;
+import org.apache.geode.admin.GemFireHealthConfig;
+import org.apache.geode.admin.internal.GemFireHealthEvaluator;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.admin.remote.HealthListenerMessage;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LoggingThreadGroup;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 /**
  * Implements a thread that monitors the health of the vm it lives in.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityAckedMessage.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityAckedMessage.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityAckedMessage.java
index ffae0fe..2733c39 100755
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityAckedMessage.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityAckedMessage.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -26,14 +26,14 @@ import java.util.concurrent.ThreadPoolExecutor;
 
 import org.apache.logging.log4j.Logger;
 
-import com.gemstone.gemfire.DataSerializer;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.internal.membership.InternalDistributedMember;
-import com.gemstone.gemfire.internal.Assert;
-import com.gemstone.gemfire.internal.OSProcess;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.DataSerializer;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
+import org.apache.geode.internal.Assert;
+import org.apache.geode.internal.OSProcess;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
 
 /**
  * A message that is sent to a given collection of managers and then

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityDistributionMessage.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityDistributionMessage.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityDistributionMessage.java
index d13927a..5b9b01c 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityDistributionMessage.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/HighPriorityDistributionMessage.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /**
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/IgnoredByManager.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/IgnoredByManager.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/IgnoredByManager.java
index 4090d3a..001087f 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/IgnoredByManager.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/IgnoredByManager.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
+package org.apache.geode.distributed.internal;
 
 /**
  * This marker indicates messages (usually {@link
diff --git a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionManager.java b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionManager.java
index df61201..1cb4ada 100644
--- a/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionManager.java
+++ b/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionManager.java
@@ -14,34 +14,34 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.gemstone.gemfire.distributed.internal;
-
-import com.gemstone.gemfire.*;
-import com.gemstone.gemfire.admin.GemFireHealthConfig;
-import com.gemstone.gemfire.distributed.DistributedMember;
-import com.gemstone.gemfire.distributed.DistributedSystemDisconnectedException;
-import com.gemstone.gemfire.distributed.Locator;
-import com.gemstone.gemfire.distributed.Role;
-import com.gemstone.gemfire.distributed.internal.locks.ElderState;
-import com.gemstone.gemfire.distributed.internal.membership.*;
-import com.gemstone.gemfire.i18n.StringId;
-import com.gemstone.gemfire.internal.*;
-import com.gemstone.gemfire.internal.admin.remote.AdminConsoleDisconnectMessage;
-import com.gemstone.gemfire.internal.admin.remote.RemoteGfManagerAgent;
-import com.gemstone.gemfire.internal.admin.remote.RemoteTransportConfig;
-import com.gemstone.gemfire.internal.cache.InitialImageOperation;
-import com.gemstone.gemfire.internal.i18n.LocalizedStrings;
-import com.gemstone.gemfire.internal.logging.LogService;
-import com.gemstone.gemfire.internal.logging.LoggingThreadGroup;
-import com.gemstone.gemfire.internal.logging.log4j.AlertAppender;
-import com.gemstone.gemfire.internal.logging.log4j.LocalizedMessage;
-import com.gemstone.gemfire.internal.logging.log4j.LogMarker;
-import com.gemstone.gemfire.internal.net.SocketCreator;
-import com.gemstone.gemfire.internal.sequencelog.MembershipLogger;
-import com.gemstone.gemfire.internal.tcp.Connection;
-import com.gemstone.gemfire.internal.tcp.ConnectionTable;
-import com.gemstone.gemfire.internal.tcp.ReenteredConnectException;
-import com.gemstone.gemfire.internal.util.concurrent.StoppableReentrantLock;
+package org.apache.geode.distributed.internal;
+
+import org.apache.geode.*;
+import org.apache.geode.admin.GemFireHealthConfig;
+import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.DistributedSystemDisconnectedException;
+import org.apache.geode.distributed.Locator;
+import org.apache.geode.distributed.Role;
+import org.apache.geode.distributed.internal.locks.ElderState;
+import org.apache.geode.distributed.internal.membership.*;
+import org.apache.geode.i18n.StringId;
+import org.apache.geode.internal.*;
+import org.apache.geode.internal.admin.remote.AdminConsoleDisconnectMessage;
+import org.apache.geode.internal.admin.remote.RemoteGfManagerAgent;
+import org.apache.geode.internal.admin.remote.RemoteTransportConfig;
+import org.apache.geode.internal.cache.InitialImageOperation;
+import org.apache.geode.internal.i18n.LocalizedStrings;
+import org.apache.geode.internal.logging.LogService;
+import org.apache.geode.internal.logging.LoggingThreadGroup;
+import org.apache.geode.internal.logging.log4j.AlertAppender;
+import org.apache.geode.internal.logging.log4j.LocalizedMessage;
+import org.apache.geode.internal.logging.log4j.LogMarker;
+import org.apache.geode.internal.net.SocketCreator;
+import org.apache.geode.internal.sequencelog.MembershipLogger;
+import org.apache.geode.internal.tcp.Connection;
+import org.apache.geode.internal.tcp.ConnectionTable;
+import org.apache.geode.internal.tcp.ReenteredConnectException;
+import org.apache.geode.internal.util.concurrent.StoppableReentrantLock;
 import org.apache.logging.log4j.Logger;
 
 import java.io.*;
@@ -89,7 +89,7 @@ public class DistributionManager
 
   /**
    * WARNING: setting this to true may break dunit tests.
-   * <p>see com.gemstone.gemfire.cache30.ClearMultiVmCallBkDUnitTest
+   * <p>see org.apache.geode.cache30.ClearMultiVmCallBkDUnitTest
    */
   public static final boolean INLINE_PROCESS = 
     !Boolean.getBoolean("DistributionManager.enqueueOrderedMessages");
@@ -177,7 +177,7 @@ public class DistributionManager
 
   /**
    * an NIO priority type
-   * @see com.gemstone.gemfire.distributed.internal.PooledDistributionMessage
+   * @see org.apache.geode.distributed.internal.PooledDistributionMessage
    * @see #SERIAL_EXECUTOR
    * @see #HIGH_PRIORITY_EXECUTOR
    * @see #WAITING_POOL_EXECUTOR
@@ -187,7 +187,7 @@ public class DistributionManager
   /**
    * an NIO priority type
    * 
-   * @see com.gemstone.gemfire.distributed.internal.SerialDistributionMessage
+   * @see org.apache.geode.distributed.internal.SerialDistributionMessage
    * @see #STANDARD_EXECUTOR
    */
   public static final int SERIAL_EXECUTOR = 74;
@@ -195,7 +195,7 @@ public class DistributionManager
   /**
    * an NIO priority type
 
-   * @see com.gemstone.gemfire.distributed.internal.HighPriorityDistributionMessage
+   * @see org.apache.geode.distributed.internal.HighPriorityDistributionMessage
    * @see #STANDARD_EXECUTOR
    */
   public static final int HIGH_PRIORITY_EXECUTOR = 75;
@@ -205,7 +205,7 @@ public class DistributionManager
   /**
    * an NIO priority type
    * 
-   * @see com.gemstone.gemfire.internal.cache.InitialImageOperation
+   * @see org.apache.geode.internal.cache.InitialImageOperation
    * @see #STANDARD_EXECUTOR
    */
   public static final int WAITING_POOL_EXECUTOR = 77;
@@ -213,7 +213,7 @@ public class DistributionManager
   /**
    * an NIO priority type
    * 
-   * @see com.gemstone.gemfire.internal.cache.InitialImageOperation
+   * @see org.apache.geode.internal.cache.InitialImageOperation
    * @see #STANDARD_EXECUTOR
    */
   public static final int PARTITIONED_REGION_EXECUTOR = 78;
@@ -222,7 +222,7 @@ public class DistributionManager
   /**
    * Executor for view related messages
    * 
-   * @see com.gemstone.gemfire.distributed.internal.membership.gms.messages.ViewAckMessage
+   * @see org.apache.geode.distributed.internal.membership.gms.messages.ViewAckMessage
    * @see #STANDARD_EXECUTOR
    */
   public static final int VIEW_EXECUTOR = 79;
@@ -390,8 +390,8 @@ public class DistributionManager
   private ThreadPoolExecutor prMetaDataCleanupThreadPool;
   
   /**
    * Thread used to decouple {@link com.gemstone.gemfire.internal.cache.partitioned.PartitionMessage}s from 
    * {@link com.gemstone.gemfire.internal.cache.DistributedCacheOperation}s </b>
    * @see #SERIAL_EXECUTOR
    */
   private ThreadPoolExecutor partitionedRegionThread;
@@ -403,7 +403,7 @@ public class DistributionManager
   private ThreadPoolExecutor serialThread;
   
   /** Message processing executor for view messages
-   * @see com.gemstone.gemfire.distributed.internal.membership.gms.messages.ViewAckMessage 
+   * @see org.apache.geode.distributed.internal.membership.gms.messages.ViewAckMessage 
    */
   private ThreadPoolExecutor viewThread;
   
@@ -2365,9 +2365,9 @@ public class DistributionManager
   /**
    * This thread processes member events as they occur.
    * 
    * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberCrashedEvent
    * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberJoinedEvent
    * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberDepartedEvent
    *
    */
   protected class MemberEventInvoker implements Runnable {
@@ -2557,10 +2557,10 @@ public class DistributionManager
   public Set addAllMembershipListenerAndGetAllIds(MembershipListener l) {
     // TO fix this deadlock:
     // "View Message Processor":
     //  waiting to lock monitor 0x080f691c (object 0xe3ba7680, a com.gemstone.gemfire.distributed.internal.DistributionManager$MembersLock),
     //  which is held by "RMI TCP Connection(259)-10.80.10.55"
     // "RMI TCP Connection(259)-10.80.10.55":
     //  waiting to lock monitor 0x080f6598 (object 0xe3bacd90, a com.gemstone.gemfire.distributed.internal.membership.jgroup.JGroupMembershipManager$ViewLock),
     //  which is held by "View Message Processor"
     // NEED to prevent view changes while installing a listener.
     DistributionChannel ch = this.channel;
@@ -3470,7 +3470,7 @@ public class DistributionManager
       for (int i = 0; i < message.getRecipients().length; i ++)
         result.add(message.getRecipients()[i]);
       return result;
-   /*   if (ex instanceof com.gemstone.gemfire.GemFireIpcResourceException) {
+   /*   if (ex instanceof org.apache.geode.GemFireIpcResourceException) {
         return;
       }*/
     }
@@ -4546,21 +4546,21 @@ public class DistributionManager
 
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.distributed.internal.DM#getRootCause()
+   * @see org.apache.geode.distributed.internal.DM#getRootCause()
    */
   public Throwable getRootCause() {
     return this.rootCause;
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.distributed.internal.DM#setRootCause(java.lang.Throwable)
+   * @see org.apache.geode.distributed.internal.DM#setRootCause(java.lang.Throwable)
    */
   public void setRootCause(Throwable t) {
     this.rootCause = t;
   }
 
   /* (non-Javadoc)
-   * @see com.gemstone.gemfire.distributed.internal.DM#getMembersOnThisHost()
+   * @see org.apache.geode.distributed.internal.DM#getMembersOnThisHost()
    * @since GemFire 5.9
    */
   public Set<InternalDistributedMember> getMembersInThisZone() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/7171cec4/geode-core/src/main/java/org/apache/geode/distributed/internal/DistributionMessage.java
----------------------------------------------------------------------
@@ -390,8 +390,8 @@ public class DistributionManager
   
   /**
-   * Thread used to decouple {@link com.gemstone.gemfire.internal.cache.partitioned.PartitionMessage}s from 
-   * {@link com.gemstone.gemfire.internal.cache.DistributedCacheOperation}s </b>
+   * Thread used to decouple {@link org.apache.geode.internal.cache.partitioned.PartitionMessage}s from 
+   * {@link org.apache.geode.internal.cache.DistributedCacheOperation}s </b>
    * @see #SERIAL_EXECUTOR
    */
@@ -2365,9 +2365,9 @@ public class DistributionManager
    * This thread processes member events as they occur.
    * 
-   * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberCrashedEvent
-   * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberJoinedEvent
-   * @see com.gemstone.gemfire.distributed.internal.DistributionManager.MemberDepartedEvent
+   * @see org.apache.geode.distributed.internal.DistributionManager.MemberCrashedEvent
+   * @see org.apache.geode.distributed.internal.DistributionManager.MemberJoinedEvent
+   * @see org.apache.geode.distributed.internal.DistributionManager.MemberDepartedEvent
    *
    */
@@ -2557,10 +2557,10 @@ public class DistributionManager
     // TO fix this deadlock:
     // "View Message Processor":
-    //  waiting to lock monitor 0x080f691c (object 0xe3ba7680, a com.gemstone.gemfire.distributed.internal.DistributionManager$MembersLock),
+    //  waiting to lock monitor 0x080f691c (object 0xe3ba7680, a org.apache.geode.distributed.internal.DistributionManager$MembersLock),
     //  which is held by "RMI TCP Connection(259)-10.80.10.55"
     // "RMI TCP Connection(259)-10.80.10.55":
@@ -2557,10 +2557,10 @@ public class DistributionManager
     //  which is held by "RMI TCP Connection(259)-10.80.10.55"
     // "RMI TCP Connection(259)-10.80.10.55":
-    //  waiting to lock monitor 0x080f6598 (object 0xe3bacd90, a com.gemstone.gemfire.distributed.internal.membership.jgroup.JGroupMembershipManager$ViewLock),
+    //  waiting to lock monitor 0x080f6598 (object 0xe3bacd90, a org.apache.geode.distributed.internal.membership.jgroup.JGroupMembershipManager$ViewLock),
     //  which is held by "View Message Processor"
     // NEED to prevent view changes while installing a listener.